@@ -10,6 +10,7 @@ import re
 import os
 import tempfile
 import operator
+import shutil
 from warnings import warn
 from datetime import datetime
 from zipfile import ZipFile, ZIP_DEFLATED
@@ -36,7 +37,7 @@ class Workbook(xmlwriter.XMLwriter):
     #
     ###########################################################################
 
-    def __init__(self, filename=None):
+    def __init__(self, filename=None, options={}):
         """
         Constructor.
 
@@ -75,7 +76,7 @@ class Workbook(xmlwriter.XMLwriter):
         self.localtime = datetime.now()
         self.num_vml_files = 0
         self.num_comment_files = 0
-        self.optimization = 0
+        self.optimization = options.get('constant_memory', 0)
         self.x_window = 240
         self.y_window = 15
         self.window_width = 16095
@@ -114,7 +115,6 @@ class Workbook(xmlwriter.XMLwriter):
         #            self.table_count,
         #            self.date_1904,
         #            self.palette, # remove
-        #            self.optimization,
         #            self.tempdir,
 
         init_data = {
@@ -122,6 +122,7 @@ class Workbook(xmlwriter.XMLwriter):
             'index': sheet_index,
             'str_table': self.str_table,
             'worksheet_meta': self.worksheet_meta,
+            'optimization': self.optimization,
         }
 
         worksheet = Worksheet()
@@ -339,6 +340,7 @@ class Workbook(xmlwriter.XMLwriter):
                 rel_filename = abs_filename.replace(dir_root, '')
                 xlsx_file.write(abs_filename, rel_filename)
 
+        shutil.rmtree(temp_dir)
         xlsx_file.close()
 
     def _check_sheetname(self, sheetname, is_chart=False):
